#include "da.h"

gint       prog_fd;
gchar     *gtkrc_tmp;
GtkWidget *preview_socket;
